<?php

add_action('wp_ajax_roadcube_verify_phone_number', 'roadcube_verify_phone_number_callback');
function roadcube_verify_phone_number_callback()
{
    if (!isset($_POST['dataset'])) {
        wp_send_json_error(array('message' => 'No data received'), 400);
        exit;
    }

    // Sanitize input data
    $token = isset($_POST['dataset']['verify_token']) ? sanitize_text_field($_POST['dataset']['verify_token']) : '';
    $code = isset($_POST['dataset']['verify_number']) ? sanitize_text_field($_POST['dataset']['verify_number']) : '';

    // Validate inputs
    if (empty($token)) {
        wp_send_json_error(array('message' => 'Token is not provided'), 400);
        exit;
    }

    if (empty($code)) {
        wp_send_json_error(array('message' => 'Given verification code is not provided'), 400);
        exit;
    }

    // Get API key securely
    $api_key = Coupon_Claimer::roadcube_get_setting('api_key');
    if (empty($api_key)) {
        wp_send_json_error(array('message' => 'API key not configured'), 500);
        exit;
    }

    // Make the API request
    $response = wp_remote_post(
        "https://api.roadcube.io/v1/p/users/attach-mobile/verification",
        array(
            'headers' => array(
                'X-API-TOKEN' => $api_key,
                'Content-Type' => 'application/json'
            ),
            'body' => wp_json_encode(array(
                'email_mobile_identifier' => $token,
                'mobile_verification_code' => $code
            )),
        )
    );

    // Handle API errors
    if (is_wp_error($response)) {
        wp_send_json_error(array('message' => 'API request failed'), 500);
        exit;
    }

    $response_body = wp_remote_retrieve_body($response);
    $output = json_decode($response_body, true);

    // Validate API response
    if (empty($output) || !is_array($output)) {
        wp_send_json_error(array('message' => 'Invalid API response'), 500);
        exit;
    }

    // Process the response
    if (isset($output['status']) && $output['status'] === 'success') {
        $email = isset($output['data']['email']) ? sanitize_email($output['data']['email']) : '';
        $mobile = isset($output['data']['mobile']) ? sanitize_text_field($output['data']['mobile']) : '';

        if ($email && $mobile) {
            $user = get_user_by('email', $email);
            if ($user) {
                update_user_meta($user->ID, 'roadcube_mobile', $mobile);
            }
        }
    }
    $output['token'] = esc_html($token);
    $output['code'] = esc_html($code);

    // Send the response
    wp_send_json_success($output);
    exit;
}

add_action('wp_ajax_roadcube_set_phone_number', 'roadcube_set_phone_number_callback');
function roadcube_set_phone_number_callback()
{

    if (!isset($_POST['dataset'])) {
        wp_send_json_error(array('message' => 'No data received'), 400);
        exit;
    }

    // Sanitize inputs
    $email = isset($_POST['dataset']['email']) ? sanitize_email($_POST['dataset']['email']) : '';
    $phone = isset($_POST['dataset']['phone']) ? sanitize_text_field($_POST['dataset']['phone']) : '';

    // Validate inputs
    if (empty($email) || !is_email($email)) {
        wp_send_json_error(array('message' => 'Invalid email address'), 400);
        exit;
    }

    if (empty($phone) || !preg_match('/^\+?[0-9]{7,15}$/', $phone)) {
        wp_send_json_error(array('message' => 'Invalid phone number'), 400);
        exit;
    }

    // Get API key
    $api_key = Coupon_Claimer::roadcube_get_setting('api_key');

    // Make the API request
    $response = wp_remote_post(
        "https://api.roadcube.io/v1/p/users/attach-mobile/init",
        array(
            'headers' => array(
                'X-API-TOKEN' => $api_key,
                'Content-Type' => 'application/json'
            ),
            'body' => wp_json_encode(array(
                'email' => $email,
                'mobile' => $phone
            )),
        )
    );

    // Handle API errors
    if (is_wp_error($response)) {
        wp_send_json_error(array('message' => 'API request failed'), 500);
        exit;
    }

    $response_body = wp_remote_retrieve_body($response);
    $decoded_response = json_decode($response_body, true);

    if (empty($decoded_response) || !is_array($decoded_response)) {
        wp_send_json_error(array('message' => 'Invalid API response'), 500);
        exit;
    }

    $decoded_response['email'] = esc_html($email);
    $decoded_response['phone'] = esc_html($phone);

    wp_send_json_success($decoded_response);
    exit;
}

add_action('wp_ajax_roadcube_sd_verify_code', 'roadcube_sd_verify_code_callback');
add_action('wp_ajax_nopriv_roadcube_sd_verify_code', 'roadcube_sd_verify_code_callback');

function roadcube_sd_verify_code_callback()
{
    if (!isset($_POST['dataset'])) {
        wp_send_json_error(array('message' => 'No data received'), 400);
        exit;
    }

    // Sanitize input data
    $data = $_POST['dataset'];
    $mobile = isset($data['mobile']) ? sanitize_text_field($data['mobile']) : '';
    $country_id = isset($data['country_id']) ? $data['country_id'] : 0;

    // Validate inputs
    if (empty($mobile)) {
        wp_send_json_error(array('message' => 'Invalid mobile number provided'), 400);
        exit;
    }

    if (empty($country_id) || !is_numeric($country_id)) {
        wp_send_json_error(array('message' => 'Invalid country ID provided'), 400);
        exit;
    }

    // Call the roadcube_user_register_init function
    $user_ini_reg_data = roadcube_user_register_init(array(
        'mobile' => $mobile,
        'country_id' => $country_id,
        'tos' => true,
        'verify_mobile' => true
    ));

    // Send the response
    wp_send_json_success($user_ini_reg_data);
    exit;
}

add_action('wp_ajax_roadcube_vfy_phone_number', 'roadcube_vfy_phone_number_callback');
add_action('wp_ajax_nopriv_roadcube_vfy_phone_number', 'roadcube_vfy_phone_number_callback');

function roadcube_vfy_phone_number_callback()
{
    if (!isset($_POST['dataset'])) {
        wp_send_json_error(array('message' => 'No data received'), 400);
        exit;
    }

    // Sanitize input data
    $data = $_POST['dataset'];
    $id = isset($data['user_registration_identifier']) ? sanitize_text_field($data['user_registration_identifier']) : '';
    $code = isset($data['mobile_verification_code']) ? sanitize_text_field($data['mobile_verification_code']) : '';

    // Validate inputs
    if (empty($id)) {
        wp_send_json_error(array('message' => 'Invalid or missing user registration identifier'), 400);
        exit;
    }

    if (empty($code)) {
        wp_send_json_error(array('message' => 'Missing mobile verification code'), 400);
        exit;
    }

    $user_ini_reg_data = roadcube_user_register_init(array(
        'user_registration_identifier' => $id,
        'mobile_verification_code' => $code,
        'mobile_verify' => true
    ));

    // Send the response
    wp_send_json_success($user_ini_reg_data);
    exit;
}


add_action('wp_ajax_roadcube_register_new_user', 'roadcube_register_new_user_callback');
add_action('wp_ajax_nopriv_roadcube_register_new_user', 'roadcube_register_new_user_callback');
function roadcube_register_new_user_callback()
{
    if (isset($_POST['dataset'])) {
        $data = $_POST['dataset'];
        $username = isset($data['username']) && !isset($data['user_exists'])  ? $data['username'] : "";
        $roadcube_email = isset($data['roadcube_email']) || !isset($data['user_exists']) ? $data['roadcube_email'] : "";
        $country_id = isset($data['country_id']) ? $data['country_id'] : '' ;
        $user_reg_id = $data['user_reg_id'];
        $mobile = $data['mobile'];
        $gender = $data['gender'];
        $dob = $data['dob'];
        $pass = isset($data['pass']) && !isset($data['user_exists']) ? $data['pass'] : "";
        $con_pass = isset($data['con_pass']) || !isset($data['user_exists']) ? $data['con_pass'] : "";
        if (!isset($data['user_exists'])) {
            $user_exists = get_user_by('login', $username);
            if ($user_exists) {
                echo wp_json_encode([
                    'status' => 'error',
                    'message' => __('Username already exists', 'roadcube'),
                    'data' => $data
                ]);
                exit;
            }

            $user_reg_data = roadcube_user_register([
                'user_registration_identifier' => $user_reg_id,
                'gender' => $gender,
                'password' => $pass,
                'password_confirmation' => $con_pass,
                'birthday' => $dob,
                "marketing" => true
            ]);
        }
        if (isset($user_reg_data['status']) && $user_reg_data['status'] == "error") {
            echo wp_json_encode($user_reg_data);
            exit;
        }
        if (!isset($data['user_exists']) || $data['user_exists'] == 0) {
            $userdata = [
                // 'user_login' => $username,
                'user_login' => $roadcube_email, //change
                'user_pass' => $pass,
                'user_email' => $roadcube_email
            ];
            $user_id = wp_insert_user($userdata);
            update_user_meta($user_id, 'roadcube_gender', $gender);
            update_user_meta($user_id, 'roadcube_birthday', $dob);
            update_user_meta($user_id, 'roadcube_mobile', $mobile);
            update_user_meta($user_id, 'roadcube_country_id', $country_id);
        } else {
            $user_id = $data['user_exists'];
            update_user_meta($user_id, 'roadcube_mobile', $mobile);
        }
        echo wp_json_encode([
            'status' => 'success',
            'roadcube_gender' => $gender,
            'roadcube_birthday' => $dob,
            'roadcube_mobile' => $mobile,
            'roadcube_country_id' => $country_id,
            'data' => $data
        ]);
        exit;
    }
    exit;
}

add_action('wp_ajax_roadcube_coupon_claim', 'roadcube_coupon_claim_callback');
function roadcube_coupon_claim_callback()
{
    if (isset($_POST['dataset'])) {
        $data = $_POST['dataset'];
        if (isset($data['checkout_claim'])) {
            $coupon_data = roadcube_coupon_claim($data['user'], $data['coupon_id']);
            if (!isset($coupon_data['status']) || $coupon_data['status'] != 'success') {
                echo wp_json_encode($coupon_data);
                exit;
            }
            $title = isset($data['title']) ? sanitize_text_field($data['title']) : '';
            $cost = isset($data['cost']) ? floatval($data['cost']) : 0;
            $cost_type = isset($data['cost_type']) ? sanitize_text_field($data['cost_type']) : '';

            $data = roadcube_user_coupon_claim($data['user']);
            $data = $data['data']['user_gifts'];
            foreach ($data as $a_voucher) {
                if ($a_voucher['title'] == $title) {
                    $data = array(
                        'status' => 'success',
                        'title' => $title,
                        'is_voucer' => true,
                        'cost' => $cost,
                        'cost_type' => $cost_type,
                        'voucher' => $a_voucher['voucher']
                    );
                    $claimed_coupons = get_user_meta(get_current_user_id(), 'roadcube_claimed_coupons', true) ?: [];
                    $claimed_coupons[] = $data;
                    update_user_meta(get_current_user_id(), 'roadcube_claimed_coupons', $claimed_coupons);
                    echo wp_json_encode($data);
                    exit;
                }
            }
            // WC()->session->add_item();
        } else {
            $data = roadcube_coupon_claim($data['user'], $data['coupon_id']);
        }
        echo wp_json_encode($data);
        exit;
    }
    exit;
}

add_action('wp_ajax_roadcube_get_available_coupons', 'roadcube_get_available_coupons_callback');
add_action('wp_ajax_nopriv_roadcube_get_available_coupons', 'roadcube_get_available_coupons_callback');

function roadcube_get_available_coupons_callback()
{
    if (!isset($_POST['dataset'])) {
        wp_send_json_error(array('message' => 'No data received'), 400);
        exit;
    }

    $data = $_POST['dataset'];
    $page = isset($data['page']) ? absint($data['page']) : 1;

    if ($page < 1) {
        wp_send_json_error(array('message' => 'Invalid page number'), 400);
        exit;
    }

    $coupons_data = roadcube_get_available_coupons($page);

    // Send success response
    wp_send_json_success($coupons_data);
    exit;
}


add_action('wp_ajax_roadcube_get_user_available_coupons', 'roadcube_get_user_available_coupons_callback');
add_action('wp_ajax_nopriv_roadcube_get_user_available_coupons', 'roadcube_get_user_available_coupons_callback');

function roadcube_get_user_available_coupons_callback()
{
    if (!isset($_POST['dataset'])) {
        wp_send_json_error(array('message' => 'No data received'), 400);
        exit;
    }

    $data = $_POST['dataset'];
    $page = isset($data['page']) ? $data['page'] : '';
    $user_email = isset($data['user_email']) ? sanitize_email($data['user_email']) : '';

    if (empty($user_email) || !is_email($user_email)) {
        wp_send_json_error(array('message' => 'Invalid or missing email address'), 400);
        exit;
    }

    $coupons_data = roadcube_get_user_available_coupons($page, $user_email);

    // Send success response
    wp_send_json_success($coupons_data);
    exit;
}
